@@ -34,7 +34,7 @@ import pytensor
 
 from pymc.backends.report import SamplerReport
 from pymc.model import modelcontext
-from pymc.pytensorf import compile_pymc
+from pymc.pytensorf import compile
 from pymc.util import get_var_name
 
 logger = logging.getLogger(__name__)
@@ -171,7 +171,7 @@ class BaseTrace(IBaseTrace):
 
         if fn is None:
             # borrow=True avoids deepcopy when inputs=output which is the case for untransformed value variables
-            fn = compile_pymc(
+            fn = compile(
                 inputs=[pytensor.In(v, borrow=True) for v in model.value_vars],
                 outputs=[pytensor.Out(v, borrow=True) for v in vars],
                 on_unused_input="ignore",
