@@ -92,14 +92,13 @@ def jax_funcify_PosDefMatrix(op, **kwargs):
 
 
 def _replace_shared_variables(graph: list[TensorVariable]) -> list[TensorVariable]:
-    """Replace shared variables in graph by their constant values
+    """Replace shared variables in graph by their constant values.
 
     Raises
     ------
     ValueError
         If any shared variable contains default_updates
     """
-
     shared_variables = [var for var in graph_inputs(graph) if isinstance(var, SharedVariable)]
 
     if any(isinstance(var.type, RandomType) for var in shared_variables):
@@ -123,8 +122,7 @@ def get_jaxified_graph(
     inputs: list[TensorVariable] | None = None,
     outputs: list[TensorVariable] | None = None,
 ) -> list[TensorVariable]:
-    """Compile an PyTensor graph into an optimized JAX function"""
-
+    """Compile a PyTensor graph into an optimized JAX function."""
     graph = _replace_shared_variables(outputs) if outputs is not None else None
 
     fgraph = FunctionGraph(inputs=inputs, outputs=graph, clone=True)
@@ -164,7 +162,7 @@ def _get_log_likelihood(
     backend: Literal["cpu", "gpu"] | None = None,
     postprocessing_vectorize: Literal["vmap", "scan"] = "scan",
 ) -> dict:
-    """Compute log-likelihood for all observations"""
+    """Compute log-likelihood for all observations."""
     elemwise_logp = model.logp(model.observed_RVs, sum=False)
     jax_fn = get_jaxified_graph(inputs=model.value_vars, outputs=elemwise_logp)
     result = _postprocess_samples(
@@ -216,7 +214,7 @@ def _get_batched_jittered_initial_points(
     jitter: bool = True,
     jitter_max_retries: int = 10,
 ) -> np.ndarray | list[np.ndarray]:
-    """Get jittered initial point in format expected by NumPyro MCMC kernel
+    """Get jittered initial point in format expected by NumPyro MCMC kernel.
 
     Returns
     -------
@@ -224,7 +222,6 @@ def _get_batched_jittered_initial_points(
         list with one item per variable and number of chains as batch dimension.
         Each item has shape `(chains, *var.shape)`
     """
-
     initial_points = _init_jitter(
         model,
         initvals,
@@ -354,7 +351,6 @@ def _sample_blackjax_nuts(
         with their respective sample stats and pointwise log likeihood values (unless
         skipped with ``idata_kwargs``).
     """
-
     import blackjax
 
     # Adapted from numpyro
